==> scorchful-0.16.0%2B1.21.9-sources.jar: com/github/thedeathlycow/scorchful/mixin/thirst/PotionEntityMixin.java <==
package com.github.thedeathlycow.scorchful.mixin.thirst;

import com.github.thedeathlycow.scorchful.config.ScorchfulConfig;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1686;
import net.minecraft.class_1937;
import net.minecraft.class_238;
import net.minecraft.class_239;
import net.minecraft.class_3857;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_1686.class)
public abstract class PotionEntityMixin extends class_3857 {
    protected PotionEntityMixin(class_1299<? extends class_3857> entityType, class_1937 world) {
        super(entityType, world);
    }

    @Inject(
            method = "onCollision",
            at = @At("HEAD")
    )
    private void onSplashPotionCollision(class_239 hitResult, CallbackInfo ci) {
        class_1937 world = this.method_73183();
        if (world.method_8608()) {
            return;
        }
        class_238 box = this.method_5829().method_1009(4.0, 2.0, 4.0);

        int waterAmount = ScorchfulConfig.getThirstConfig().getSoakingFromSplashPotions();

        world.method_18467(class_1309.class, box)
                .forEach(
                        entity -> {
                            int wetTicks = entity.thermoo$getWetTicks();
                            entity.thermoo$setWetTicks(wetTicks + waterAmount);
                        }
                );
    }
}

==> scorchful-0.16.2%2B1.21.10-sources.jar: com/github/thedeathlycow/scorchful/mixin/thirst/PotionEntityMixin.java <==
package com.github.thedeathlycow.scorchful.mixin.thirst;

import com.github.thedeathlycow.scorchful.config.ScorchfulConfig;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1686;
import net.minecraft.class_1937;
import net.minecraft.class_238;
import net.minecraft.class_239;
import net.minecraft.class_3857;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_1686.class)
public abstract class PotionEntityMixin extends class_3857 {
    protected PotionEntityMixin(class_1299<? extends class_3857> entityType, class_1937 world) {
        super(entityType, world);
    }

    @Inject(
            method = "onCollision",
            at = @At("HEAD")
    )
    private void onSplashPotionCollision(class_239 hitResult, CallbackInfo ci) {
        class_1937 world = this.method_73183();
        if (world.method_8608()) {
            return;
        }
        class_238 box = this.method_5829().method_1009(4.0, 2.0, 4.0);

        int waterAmount = ScorchfulConfig.getEntityConfig().getSoakingFromSplashPotions();

        world.method_18467(class_1309.class, box)
                .forEach(
                        entity -> {
                            int wetTicks = entity.thermoo$getWetTicks();
                            entity.thermoo$setWetTicks(wetTicks + waterAmount);
                        }
                );
    }
}
